/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:expandtab:shiftwidth=2:tabstop=2:
 **/
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

// I am taking the first step in the hope that  this file will  become 'the' 
// repository of #defines for CID's and CONTRACTID's of implementations of 
// all interfaces in nsUConvModule and be included by any file that wants 
// to refers to one or more of implementations by CID/CONTRACTID. 
// see bug 162765 comment #33. 
  
// {2b026890-5a2e-4981-ada2-a600358947b4}
#define NS_UTF8CONVERTERSERVICE_CID { 0x2b026890, 0x5a2e, 0x4981, \
                            { 0xad, 0xa2, 0xa6, 0x00, 0x35, 0x89, 0x47, 0xb4 } }
#define NS_UTF8CONVERTERSERVICE_CONTRACTID "@mozilla.org/intl/utf8converterservice;1"

