/* THIS FILE IS AUTOGENERATED - DO NOT EDIT */

#ifndef mozilla_dom_GeneratedAtomList_h__
#define mozilla_dom_GeneratedAtomList_h__

#include "mozilla/dom/BindingUtils.h"

namespace mozilla {
namespace dom {

struct AnimationEventInitAtoms
{
  InternedStringId animationName_id;
  InternedStringId elapsedTime_id;
  InternedStringId pseudoElement_id;
};

struct AppInfoAtoms
{
  InternedStringId isCoreApp_id;
  InternedStringId path_id;
};

struct AppNotificationServiceOptionsAtoms
{
  InternedStringId dir_id;
  InternedStringId id_id;
  InternedStringId lang_id;
  InternedStringId manifestURL_id;
  InternedStringId tag_id;
  InternedStringId textClickable_id;
};

struct ArchiveReaderOptionsAtoms
{
  InternedStringId encoding_id;
};

struct AsyncScrollEventDetailAtoms
{
  InternedStringId height_id;
  InternedStringId left_id;
  InternedStringId scrollHeight_id;
  InternedStringId scrollWidth_id;
  InternedStringId top_id;
  InternedStringId width_id;
};

struct BlobEventInitAtoms
{
  InternedStringId data_id;
};

struct BlobPropertyBagAtoms
{
  InternedStringId endings_id;
  InternedStringId type_id;
};

struct CFStateChangeEventInitAtoms
{
  InternedStringId action_id;
  InternedStringId number_id;
  InternedStringId reason_id;
  InternedStringId serviceClass_id;
  InternedStringId success_id;
  InternedStringId timeSeconds_id;
};

struct CallEventInitAtoms
{
  InternedStringId call_id;
};

struct CallGroupErrorEventInitAtoms
{
  InternedStringId message_id;
  InternedStringId name_id;
};

struct CameraConfigurationAtoms
{
  InternedStringId mode_id;
  InternedStringId previewSize_id;
  InternedStringId recorderProfile_id;
};

struct CameraPictureOptionsAtoms
{
  InternedStringId dateTime_id;
  InternedStringId fileFormat_id;
  InternedStringId pictureSize_id;
  InternedStringId position_id;
  InternedStringId rotation_id;
};

struct CameraPositionAtoms
{
  InternedStringId altitude_id;
  InternedStringId latitude_id;
  InternedStringId longitude_id;
  InternedStringId timestamp_id;
};

struct CameraRecorderOptionsAtoms
{
  InternedStringId profile_id;
  InternedStringId rotation_id;
};

struct CameraRegionAtoms
{
  InternedStringId bottom_id;
  InternedStringId left_id;
  InternedStringId right_id;
  InternedStringId top_id;
  InternedStringId weight_id;
};

struct CameraSizeAtoms
{
  InternedStringId height_id;
  InternedStringId width_id;
};

struct CameraStartRecordingOptionsAtoms
{
  InternedStringId maxFileSizeBytes_id;
  InternedStringId maxVideoLengthMs_id;
  InternedStringId rotation_id;
};

struct ClipboardEventInitAtoms
{
  InternedStringId data_id;
  InternedStringId dataType_id;
};

struct CloseEventInitAtoms
{
  InternedStringId code_id;
  InternedStringId reason_id;
  InternedStringId wasClean_id;
};

struct CompositionClauseParametersAtoms
{
  InternedStringId length_id;
  InternedStringId selectionType_id;
};

struct ConnStatusDictAtoms
{
  InternedStringId status_id;
};

struct ContactAddressAtoms
{
  InternedStringId countryName_id;
  InternedStringId locality_id;
  InternedStringId postalCode_id;
  InternedStringId pref_id;
  InternedStringId region_id;
  InternedStringId streetAddress_id;
  InternedStringId type_id;
};

struct ContactFieldAtoms
{
  InternedStringId pref_id;
  InternedStringId type_id;
  InternedStringId value_id;
};

struct ContactFindOptionsAtoms
{
  InternedStringId filterBy_id;
  InternedStringId filterLimit_id;
  InternedStringId filterOp_id;
  InternedStringId filterValue_id;
};

struct ContactFindSortOptionsAtoms
{
  InternedStringId sortBy_id;
  InternedStringId sortOrder_id;
};

struct ContactPropertiesAtoms
{
  InternedStringId additionalName_id;
  InternedStringId adr_id;
  InternedStringId anniversary_id;
  InternedStringId bday_id;
  InternedStringId category_id;
  InternedStringId email_id;
  InternedStringId familyName_id;
  InternedStringId genderIdentity_id;
  InternedStringId givenName_id;
  InternedStringId honorificPrefix_id;
  InternedStringId honorificSuffix_id;
  InternedStringId impp_id;
  InternedStringId jobTitle_id;
  InternedStringId key_id;
  InternedStringId name_id;
  InternedStringId nickname_id;
  InternedStringId note_id;
  InternedStringId org_id;
  InternedStringId photo_id;
  InternedStringId sex_id;
  InternedStringId tel_id;
  InternedStringId url_id;
};

struct ContactTelFieldAtoms
{
  InternedStringId carrier_id;
};

struct ContextAttributes2DAtoms
{
  InternedStringId willReadFrequently_id;
};

struct CustomEventInitAtoms
{
  InternedStringId detail_id;
};

struct DNSCacheDictAtoms
{
  InternedStringId entries_id;
};

struct DNSLookupDictAtoms
{
  InternedStringId address_id;
  InternedStringId answer_id;
  InternedStringId error_id;
};

struct DOMFileMetadataParametersAtoms
{
  InternedStringId lastModified_id;
  InternedStringId size_id;
};

struct DOMTransactionEventInitAtoms
{
  InternedStringId transactions_id;
};

struct DOMWindowResizeEventDetailAtoms
{
  InternedStringId height_id;
  InternedStringId width_id;
};

struct DataErrorEventInitAtoms
{
  InternedStringId message_id;
};

struct DataStoreChangeEventInitAtoms
{
  InternedStringId id_id;
  InternedStringId operation_id;
  InternedStringId revisionId_id;
};

struct DataStoreTaskAtoms
{
  InternedStringId data_id;
  InternedStringId id_id;
  InternedStringId operation_id;
  InternedStringId revisionId_id;
};

struct DeviceAccelerationInitAtoms
{
  InternedStringId x_id;
  InternedStringId y_id;
  InternedStringId z_id;
};

struct DeviceLightEventInitAtoms
{
  InternedStringId value_id;
};

struct DeviceMotionEventInitAtoms
{
  InternedStringId acceleration_id;
  InternedStringId accelerationIncludingGravity_id;
  InternedStringId interval_id;
  InternedStringId rotationRate_id;
};

struct DeviceOrientationEventInitAtoms
{
  InternedStringId absolute_id;
  InternedStringId alpha_id;
  InternedStringId beta_id;
  InternedStringId gamma_id;
};

struct DeviceProximityEventInitAtoms
{
  InternedStringId max_id;
  InternedStringId min_id;
  InternedStringId value_id;
};

struct DeviceRotationRateInitAtoms
{
  InternedStringId alpha_id;
  InternedStringId beta_id;
  InternedStringId gamma_id;
};

struct DeviceStorageChangeEventInitAtoms
{
  InternedStringId path_id;
  InternedStringId reason_id;
};

struct DeviceStorageEnumerationParametersAtoms
{
  InternedStringId since_id;
};

struct DnsCacheEntryAtoms
{
  InternedStringId expiration_id;
  InternedStringId family_id;
  InternedStringId hostaddr_id;
  InternedStringId hostname_id;
};

struct DownloadEventInitAtoms
{
  InternedStringId download_id;
};

struct ElementRegistrationOptionsAtoms
{
  InternedStringId lifecycle_id;
  InternedStringId prototype_id;
};

struct ElementReplaceEventInitAtoms
{
  InternedStringId upgrade_id;
};

struct ErrorEventInitAtoms
{
  InternedStringId column_id;
  InternedStringId filename_id;
  InternedStringId lineno_id;
  InternedStringId message_id;
};

struct EventInitAtoms
{
  InternedStringId bubbles_id;
  InternedStringId cancelable_id;
};

struct EventSourceInitAtoms
{
  InternedStringId withCredentials_id;
};

struct FilePropertyBagAtoms
{
  InternedStringId name_id;
};

struct FocusEventInitAtoms
{
  InternedStringId relatedTarget_id;
};

struct GamepadAxisMoveEventInitAtoms
{
  InternedStringId axis_id;
  InternedStringId value_id;
};

struct GamepadButtonEventInitAtoms
{
  InternedStringId button_id;
};

struct GamepadEventInitAtoms
{
  InternedStringId gamepad_id;
};

struct GetNotificationOptionsAtoms
{
  InternedStringId tag_id;
};

struct HalfOpenInfoDictAtoms
{
  InternedStringId speculative_id;
};

struct HashChangeEventInitAtoms
{
  InternedStringId newURL_id;
  InternedStringId oldURL_id;
};

struct HttpConnDictAtoms
{
  InternedStringId connections_id;
};

struct HttpConnInfoAtoms
{
  InternedStringId protocolVersion_id;
  InternedStringId rtt_id;
  InternedStringId ttl_id;
};

struct HttpConnectionElementAtoms
{
  InternedStringId active_id;
  InternedStringId halfOpens_id;
  InternedStringId host_id;
  InternedStringId idle_id;
  InternedStringId port_id;
  InternedStringId spdy_id;
  InternedStringId ssl_id;
};

struct IDBIndexParametersAtoms
{
  InternedStringId multiEntry_id;
  InternedStringId unique_id;
};

struct IDBObjectStoreParametersAtoms
{
  InternedStringId autoIncrement_id;
  InternedStringId keyPath_id;
};

struct IDBOpenDBOptionsAtoms
{
  InternedStringId storage_id;
  InternedStringId version_id;
};

struct IDBVersionChangeEventInitAtoms
{
  InternedStringId newVersion_id;
  InternedStringId oldVersion_id;
};

struct IccChangeEventInitAtoms
{
  InternedStringId iccId_id;
};

struct InspectorRGBTripleAtoms
{
  InternedStringId b_id;
  InternedStringId g_id;
  InternedStringId r_id;
};

struct LifecycleCallbacksAtoms
{
  InternedStringId created_id;
};

struct MediaConstraintSetAtoms
{
  InternedStringId MozBundleOnly_id;
  InternedStringId MozDontOfferDataChannel_id;
  InternedStringId OfferToReceiveAudio_id;
  InternedStringId OfferToReceiveVideo_id;
};

struct MediaConstraintsAtoms
{
  InternedStringId mandatory_id;
  InternedStringId optional_id;
};

struct MediaConstraintsInternalAtoms
{
  InternedStringId mandatory_id;
  InternedStringId optional_id;
};

struct MediaStreamConstraintsAtoms
{
  InternedStringId audio_id;
  InternedStringId fake_id;
  InternedStringId picture_id;
  InternedStringId video_id;
};

struct MediaStreamConstraintsInternalAtoms
{
  InternedStringId audio_id;
  InternedStringId audiom_id;
  InternedStringId fake_id;
  InternedStringId picture_id;
  InternedStringId video_id;
  InternedStringId videom_id;
};

struct MediaStreamEventInitAtoms
{
  InternedStringId stream_id;
};

struct MediaTrackConstraintSetAtoms
{
  InternedStringId facingMode_id;
};

struct MediaTrackConstraintsAtoms
{
  InternedStringId mandatory_id;
  InternedStringId optional_id;
};

struct MediaTrackConstraintsInternalAtoms
{
  InternedStringId mandatory_id;
  InternedStringId optional_id;
};

struct MessageEventInitAtoms
{
  InternedStringId data_id;
  InternedStringId lastEventId_id;
  InternedStringId origin_id;
  InternedStringId ports_id;
  InternedStringId source_id;
};

struct MmsAttachmentAtoms
{
  InternedStringId content_id;
  InternedStringId id_id;
  InternedStringId location_id;
};

struct MmsParametersAtoms
{
  InternedStringId attachments_id;
  InternedStringId receivers_id;
  InternedStringId smil_id;
  InternedStringId subject_id;
};

struct MmsSendParametersAtoms
{
  InternedStringId serviceId_id;
};

struct MouseEventInitAtoms
{
  InternedStringId altKey_id;
  InternedStringId bubbles_id;
  InternedStringId button_id;
  InternedStringId buttons_id;
  InternedStringId cancelable_id;
  InternedStringId clientX_id;
  InternedStringId clientY_id;
  InternedStringId ctrlKey_id;
  InternedStringId detail_id;
  InternedStringId metaKey_id;
  InternedStringId relatedTarget_id;
  InternedStringId screenX_id;
  InternedStringId screenY_id;
  InternedStringId shiftKey_id;
  InternedStringId view_id;
};

struct MozApplicationEventInitAtoms
{
  InternedStringId application_id;
};

struct MozContactChangeEventInitAtoms
{
  InternedStringId contactID_id;
  InternedStringId reason_id;
};

struct MozEmergencyCbModeEventInitAtoms
{
  InternedStringId active_id;
  InternedStringId timeoutMs_id;
};

struct MozInterAppMessageEventInitAtoms
{
  InternedStringId data_id;
};

struct MozMmsEventInitAtoms
{
  InternedStringId message_id;
};

struct MozOtaStatusEventInitAtoms
{
  InternedStringId status_id;
};

struct MozSettingsEventInitAtoms
{
  InternedStringId settingName_id;
  InternedStringId settingValue_id;
};

struct MozSmsEventInitAtoms
{
  InternedStringId message_id;
};

struct MozStkCommandEventInitAtoms
{
  InternedStringId command_id;
};

struct MozXMLHttpRequestParametersAtoms
{
  InternedStringId mozAnon_id;
  InternedStringId mozSystem_id;
};

struct MutationObserverInitAtoms
{
  InternedStringId attributeFilter_id;
  InternedStringId attributeOldValue_id;
  InternedStringId attributes_id;
  InternedStringId characterData_id;
  InternedStringId characterDataOldValue_id;
  InternedStringId childList_id;
  InternedStringId subtree_id;
};

struct MutationObservingInfoAtoms
{
  InternedStringId observedNode_id;
};

struct NetworkCommandOptionsAtoms
{
  InternedStringId cmd_id;
  InternedStringId curExternalIfname_id;
  InternedStringId curInternalIfname_id;
  InternedStringId date_id;
  InternedStringId dns1_id;
  InternedStringId dns1_str_id;
  InternedStringId dns2_id;
  InternedStringId dns2_str_id;
  InternedStringId enable_id;
  InternedStringId enabled_id;
  InternedStringId endIp_id;
  InternedStringId externalIfname_id;
  InternedStringId gateway_id;
  InternedStringId gateway_str_id;
  InternedStringId hostnames_id;
  InternedStringId id_id;
  InternedStringId ifname_id;
  InternedStringId interfaceList_id;
  InternedStringId internalIfname_id;
  InternedStringId ip_id;
  InternedStringId isAsync_id;
  InternedStringId key_id;
  InternedStringId link_id;
  InternedStringId maskLength_id;
  InternedStringId mode_id;
  InternedStringId netmask_id;
  InternedStringId oldIfname_id;
  InternedStringId preExternalIfname_id;
  InternedStringId preInternalIfname_id;
  InternedStringId prefix_id;
  InternedStringId report_id;
  InternedStringId rxBytes_id;
  InternedStringId security_id;
  InternedStringId serverIp_id;
  InternedStringId ssid_id;
  InternedStringId startIp_id;
  InternedStringId threshold_id;
  InternedStringId txBytes_id;
  InternedStringId usbEndIp_id;
  InternedStringId usbStartIp_id;
  InternedStringId wifiEndIp_id;
  InternedStringId wifiStartIp_id;
  InternedStringId wifictrlinterfacename_id;
};

struct NetworkResultOptionsAtoms
{
  InternedStringId broadcast_id;
  InternedStringId curExternalIfname_id;
  InternedStringId curInternalIfname_id;
  InternedStringId date_id;
  InternedStringId enable_id;
  InternedStringId error_id;
  InternedStringId id_id;
  InternedStringId reason_id;
  InternedStringId result_id;
  InternedStringId resultCode_id;
  InternedStringId resultReason_id;
  InternedStringId ret_id;
  InternedStringId rxBytes_id;
  InternedStringId success_id;
  InternedStringId topic_id;
  InternedStringId txBytes_id;
};

struct NotificationOptionsAtoms
{
  InternedStringId body_id;
  InternedStringId dir_id;
  InternedStringId icon_id;
  InternedStringId lang_id;
  InternedStringId tag_id;
};

struct OpenWindowEventDetailAtoms
{
  InternedStringId features_id;
  InternedStringId frameElement_id;
  InternedStringId name_id;
  InternedStringId url_id;
};

struct PageTransitionEventInitAtoms
{
  InternedStringId persisted_id;
};

struct PointerEventInitAtoms
{
  InternedStringId height_id;
  InternedStringId isPrimary_id;
  InternedStringId pointerId_id;
  InternedStringId pointerType_id;
  InternedStringId pressure_id;
  InternedStringId tiltX_id;
  InternedStringId tiltY_id;
  InternedStringId width_id;
};

struct PopStateEventInitAtoms
{
  InternedStringId state_id;
};

struct PopupBlockedEventInitAtoms
{
  InternedStringId popupWindowFeatures_id;
  InternedStringId popupWindowName_id;
  InternedStringId popupWindowURI_id;
  InternedStringId requestingWindow_id;
};

struct PositionOptionsAtoms
{
  InternedStringId enableHighAccuracy_id;
  InternedStringId maximumAge_id;
  InternedStringId timeout_id;
};

struct ProgressEventInitAtoms
{
  InternedStringId lengthComputable_id;
  InternedStringId loaded_id;
  InternedStringId total_id;
};

struct RTCCodecStatsAtoms
{
  InternedStringId channels_id;
  InternedStringId clockRate_id;
  InternedStringId codec_id;
  InternedStringId parameters_id;
  InternedStringId payloadType_id;
};

struct RTCConfigurationAtoms
{
  InternedStringId iceServers_id;
};

struct RTCDataChannelEventInitAtoms
{
  InternedStringId channel_id;
};

struct RTCDataChannelInitAtoms
{
  InternedStringId id_id;
  InternedStringId maxRetransmitNum_id;
  InternedStringId maxRetransmitTime_id;
  InternedStringId maxRetransmits_id;
  InternedStringId negotiated_id;
  InternedStringId ordered_id;
  InternedStringId outOfOrderAllowed_id;
  InternedStringId preset_id;
  InternedStringId protocol_id;
  InternedStringId stream_id;
};

struct RTCIceCandidateInitAtoms
{
  InternedStringId candidate_id;
  InternedStringId sdpMLineIndex_id;
  InternedStringId sdpMid_id;
};

struct RTCIceCandidatePairStatsAtoms
{
  InternedStringId componentId_id;
  InternedStringId localCandidateId_id;
  InternedStringId mozPriority_id;
  InternedStringId nominated_id;
  InternedStringId readable_id;
  InternedStringId remoteCandidateId_id;
  InternedStringId selected_id;
  InternedStringId state_id;
};

struct RTCIceCandidateStatsAtoms
{
  InternedStringId candidateId_id;
  InternedStringId candidateType_id;
  InternedStringId componentId_id;
  InternedStringId ipAddress_id;
  InternedStringId portNumber_id;
};

struct RTCIceComponentStatsAtoms
{
  InternedStringId activeConnection_id;
  InternedStringId bytesReceived_id;
  InternedStringId bytesSent_id;
  InternedStringId component_id;
  InternedStringId transportId_id;
};

struct RTCIceServerAtoms
{
  InternedStringId credential_id;
  InternedStringId url_id;
  InternedStringId username_id;
};

struct RTCInboundRTPStreamStatsAtoms
{
  InternedStringId bytesReceived_id;
  InternedStringId jitter_id;
  InternedStringId packetsReceived_id;
};

struct RTCMediaStreamStatsAtoms
{
  InternedStringId streamIdentifier_id;
  InternedStringId trackIds_id;
};

struct RTCMediaStreamTrackStatsAtoms
{
  InternedStringId audioLevel_id;
  InternedStringId first_id;
  InternedStringId frameHeight_id;
  InternedStringId frameWidth_id;
  InternedStringId framesDecoded_id;
  InternedStringId framesPerSecond_id;
  InternedStringId framesReceived_id;
  InternedStringId framesSent_id;
  InternedStringId remoteSource_id;
  InternedStringId ssrcIds_id;
  InternedStringId trackIdentifier_id;
};

struct RTCOutboundRTPStreamStatsAtoms
{
  InternedStringId bytesSent_id;
  InternedStringId packetsSent_id;
};

struct RTCPeerConnectionIceEventInitAtoms
{
  InternedStringId candidate_id;
};

struct RTCRTPStreamStatsAtoms
{
  InternedStringId codecId_id;
  InternedStringId isRemote_id;
  InternedStringId mediaTrackId_id;
  InternedStringId remoteId_id;
  InternedStringId ssrc_id;
  InternedStringId transportId_id;
};

struct RTCSessionDescriptionInitAtoms
{
  InternedStringId sdp_id;
  InternedStringId type_id;
};

struct RTCStatsAtoms
{
  InternedStringId id_id;
  InternedStringId timestamp_id;
  InternedStringId type_id;
};

struct RTCStatsReportInternalAtoms
{
  InternedStringId codecStats_id;
  InternedStringId iceCandidatePairStats_id;
  InternedStringId iceCandidateStats_id;
  InternedStringId iceComponentStats_id;
  InternedStringId inboundRTPStreamStats_id;
  InternedStringId mediaStreamStats_id;
  InternedStringId mediaStreamTrackStats_id;
  InternedStringId outboundRTPStreamStats_id;
  InternedStringId pcid_id;
  InternedStringId rtpStreamStats_id;
  InternedStringId transportStats_id;
};

struct RTCTransportStatsAtoms
{
  InternedStringId bytesReceived_id;
  InternedStringId bytesSent_id;
};

struct RecordErrorEventInitAtoms
{
  InternedStringId name_id;
};

struct ScrollOptionsAtoms
{
  InternedStringId behavior_id;
};

struct SettingChangeAtoms
{
  InternedStringId settingName_id;
  InternedStringId settingValue_id;
};

struct SmartCardEventInitAtoms
{
  InternedStringId tokenName_id;
};

struct SmsSendParametersAtoms
{
  InternedStringId serviceId_id;
};

struct SocketElementAtoms
{
  InternedStringId active_id;
  InternedStringId host_id;
  InternedStringId port_id;
  InternedStringId received_id;
  InternedStringId sent_id;
  InternedStringId tcp_id;
};

struct SocketsDictAtoms
{
  InternedStringId received_id;
  InternedStringId sent_id;
  InternedStringId sockets_id;
};

struct SpeechRecognitionErrorInitAtoms
{
  InternedStringId error_id;
  InternedStringId message_id;
};

struct SpeechRecognitionEventInitAtoms
{
  InternedStringId emma_id;
  InternedStringId interpretation_id;
  InternedStringId resultIndex_id;
  InternedStringId results_id;
};

struct SpeechSynthesisEventInitAtoms
{
  InternedStringId charIndex_id;
  InternedStringId elapsedTime_id;
  InternedStringId name_id;
};

struct StorageEventInitAtoms
{
  InternedStringId key_id;
  InternedStringId newValue_id;
  InternedStringId oldValue_id;
  InternedStringId storageArea_id;
  InternedStringId url_id;
};

struct StyleRuleChangeEventInitAtoms
{
  InternedStringId rule_id;
  InternedStringId stylesheet_id;
};

struct StyleSheetApplicableStateChangeEventInitAtoms
{
  InternedStringId applicable_id;
  InternedStringId stylesheet_id;
};

struct StyleSheetChangeEventInitAtoms
{
  InternedStringId documentSheet_id;
  InternedStringId stylesheet_id;
};

struct TextDecodeOptionsAtoms
{
  InternedStringId stream_id;
};

struct TextDecoderOptionsAtoms
{
  InternedStringId fatal_id;
};

struct TextEncodeOptionsAtoms
{
  InternedStringId stream_id;
};

struct TrackEventInitAtoms
{
  InternedStringId track_id;
};

struct TransitionEventInitAtoms
{
  InternedStringId elapsedTime_id;
  InternedStringId propertyName_id;
  InternedStringId pseudoElement_id;
};

struct UIEventInitAtoms
{
  InternedStringId detail_id;
  InternedStringId view_id;
};

struct USSDReceivedEventInitAtoms
{
  InternedStringId message_id;
  InternedStringId sessionEnded_id;
};

struct UserProximityEventInitAtoms
{
  InternedStringId near_id;
};

struct WebGLContextAttributesAtoms
{
  InternedStringId alpha_id;
  InternedStringId antialias_id;
  InternedStringId depth_id;
  InternedStringId premultipliedAlpha_id;
  InternedStringId preserveDrawingBuffer_id;
  InternedStringId stencil_id;
};

struct WebSocketDictAtoms
{
  InternedStringId websockets_id;
};

struct WebSocketElementAtoms
{
  InternedStringId encrypted_id;
  InternedStringId hostport_id;
  InternedStringId msgreceived_id;
  InternedStringId msgsent_id;
  InternedStringId receivedsize_id;
  InternedStringId sentsize_id;
};

struct WheelEventInitAtoms
{
  InternedStringId deltaMode_id;
  InternedStringId deltaX_id;
  InternedStringId deltaY_id;
  InternedStringId deltaZ_id;
};

struct WifiCommandOptionsAtoms
{
  InternedStringId cmd_id;
  InternedStringId defaultValue_id;
  InternedStringId dns1_id;
  InternedStringId dns2_id;
  InternedStringId gateway_id;
  InternedStringId id_id;
  InternedStringId ifname_id;
  InternedStringId ipaddr_id;
  InternedStringId key_id;
  InternedStringId mask_id;
  InternedStringId request_id;
  InternedStringId route_id;
  InternedStringId value_id;
};

struct WifiResultOptionsAtoms
{
  InternedStringId broadcast_str_id;
  InternedStringId dns1_id;
  InternedStringId dns1_str_id;
  InternedStringId dns2_id;
  InternedStringId dns2_str_id;
  InternedStringId error_id;
  InternedStringId gateway_id;
  InternedStringId gateway_str_id;
  InternedStringId id_id;
  InternedStringId ipaddr_id;
  InternedStringId ipaddr_str_id;
  InternedStringId lease_id;
  InternedStringId mask_id;
  InternedStringId mask_str_id;
  InternedStringId reply_id;
  InternedStringId route_id;
  InternedStringId server_id;
  InternedStringId server_str_id;
  InternedStringId status_id;
  InternedStringId value_id;
  InternedStringId vendor_str_id;
};

struct WorkerConsoleStackAtoms
{
  InternedStringId filename_id;
  InternedStringId functionName_id;
  InternedStringId language_id;
  InternedStringId lineNumber_id;
};

struct PerThreadAtomCache : public AnimationEventInitAtoms,
                            public AppInfoAtoms,
                            public AppNotificationServiceOptionsAtoms,
                            public ArchiveReaderOptionsAtoms,
                            public AsyncScrollEventDetailAtoms,
                            public BlobEventInitAtoms,
                            public BlobPropertyBagAtoms,
                            public CFStateChangeEventInitAtoms,
                            public CallEventInitAtoms,
                            public CallGroupErrorEventInitAtoms,
                            public CameraConfigurationAtoms,
                            public CameraPictureOptionsAtoms,
                            public CameraPositionAtoms,
                            public CameraRecorderOptionsAtoms,
                            public CameraRegionAtoms,
                            public CameraSizeAtoms,
                            public CameraStartRecordingOptionsAtoms,
                            public ClipboardEventInitAtoms,
                            public CloseEventInitAtoms,
                            public CompositionClauseParametersAtoms,
                            public ConnStatusDictAtoms,
                            public ContactAddressAtoms,
                            public ContactFieldAtoms,
                            public ContactFindOptionsAtoms,
                            public ContactFindSortOptionsAtoms,
                            public ContactPropertiesAtoms,
                            public ContactTelFieldAtoms,
                            public ContextAttributes2DAtoms,
                            public CustomEventInitAtoms,
                            public DNSCacheDictAtoms,
                            public DNSLookupDictAtoms,
                            public DOMFileMetadataParametersAtoms,
                            public DOMTransactionEventInitAtoms,
                            public DOMWindowResizeEventDetailAtoms,
                            public DataErrorEventInitAtoms,
                            public DataStoreChangeEventInitAtoms,
                            public DataStoreTaskAtoms,
                            public DeviceAccelerationInitAtoms,
                            public DeviceLightEventInitAtoms,
                            public DeviceMotionEventInitAtoms,
                            public DeviceOrientationEventInitAtoms,
                            public DeviceProximityEventInitAtoms,
                            public DeviceRotationRateInitAtoms,
                            public DeviceStorageChangeEventInitAtoms,
                            public DeviceStorageEnumerationParametersAtoms,
                            public DnsCacheEntryAtoms,
                            public DownloadEventInitAtoms,
                            public ElementRegistrationOptionsAtoms,
                            public ElementReplaceEventInitAtoms,
                            public ErrorEventInitAtoms,
                            public EventInitAtoms,
                            public EventSourceInitAtoms,
                            public FilePropertyBagAtoms,
                            public FocusEventInitAtoms,
                            public GamepadAxisMoveEventInitAtoms,
                            public GamepadButtonEventInitAtoms,
                            public GamepadEventInitAtoms,
                            public GetNotificationOptionsAtoms,
                            public HalfOpenInfoDictAtoms,
                            public HashChangeEventInitAtoms,
                            public HttpConnDictAtoms,
                            public HttpConnInfoAtoms,
                            public HttpConnectionElementAtoms,
                            public IDBIndexParametersAtoms,
                            public IDBObjectStoreParametersAtoms,
                            public IDBOpenDBOptionsAtoms,
                            public IDBVersionChangeEventInitAtoms,
                            public IccChangeEventInitAtoms,
                            public InspectorRGBTripleAtoms,
                            public LifecycleCallbacksAtoms,
                            public MediaConstraintSetAtoms,
                            public MediaConstraintsAtoms,
                            public MediaConstraintsInternalAtoms,
                            public MediaStreamConstraintsAtoms,
                            public MediaStreamConstraintsInternalAtoms,
                            public MediaStreamEventInitAtoms,
                            public MediaTrackConstraintSetAtoms,
                            public MediaTrackConstraintsAtoms,
                            public MediaTrackConstraintsInternalAtoms,
                            public MessageEventInitAtoms,
                            public MmsAttachmentAtoms,
                            public MmsParametersAtoms,
                            public MmsSendParametersAtoms,
                            public MouseEventInitAtoms,
                            public MozApplicationEventInitAtoms,
                            public MozContactChangeEventInitAtoms,
                            public MozEmergencyCbModeEventInitAtoms,
                            public MozInterAppMessageEventInitAtoms,
                            public MozMmsEventInitAtoms,
                            public MozOtaStatusEventInitAtoms,
                            public MozSettingsEventInitAtoms,
                            public MozSmsEventInitAtoms,
                            public MozStkCommandEventInitAtoms,
                            public MozXMLHttpRequestParametersAtoms,
                            public MutationObserverInitAtoms,
                            public MutationObservingInfoAtoms,
                            public NetworkCommandOptionsAtoms,
                            public NetworkResultOptionsAtoms,
                            public NotificationOptionsAtoms,
                            public OpenWindowEventDetailAtoms,
                            public PageTransitionEventInitAtoms,
                            public PointerEventInitAtoms,
                            public PopStateEventInitAtoms,
                            public PopupBlockedEventInitAtoms,
                            public PositionOptionsAtoms,
                            public ProgressEventInitAtoms,
                            public RTCCodecStatsAtoms,
                            public RTCConfigurationAtoms,
                            public RTCDataChannelEventInitAtoms,
                            public RTCDataChannelInitAtoms,
                            public RTCIceCandidateInitAtoms,
                            public RTCIceCandidatePairStatsAtoms,
                            public RTCIceCandidateStatsAtoms,
                            public RTCIceComponentStatsAtoms,
                            public RTCIceServerAtoms,
                            public RTCInboundRTPStreamStatsAtoms,
                            public RTCMediaStreamStatsAtoms,
                            public RTCMediaStreamTrackStatsAtoms,
                            public RTCOutboundRTPStreamStatsAtoms,
                            public RTCPeerConnectionIceEventInitAtoms,
                            public RTCRTPStreamStatsAtoms,
                            public RTCSessionDescriptionInitAtoms,
                            public RTCStatsAtoms,
                            public RTCStatsReportInternalAtoms,
                            public RTCTransportStatsAtoms,
                            public RecordErrorEventInitAtoms,
                            public ScrollOptionsAtoms,
                            public SettingChangeAtoms,
                            public SmartCardEventInitAtoms,
                            public SmsSendParametersAtoms,
                            public SocketElementAtoms,
                            public SocketsDictAtoms,
                            public SpeechRecognitionErrorInitAtoms,
                            public SpeechRecognitionEventInitAtoms,
                            public SpeechSynthesisEventInitAtoms,
                            public StorageEventInitAtoms,
                            public StyleRuleChangeEventInitAtoms,
                            public StyleSheetApplicableStateChangeEventInitAtoms,
                            public StyleSheetChangeEventInitAtoms,
                            public TextDecodeOptionsAtoms,
                            public TextDecoderOptionsAtoms,
                            public TextEncodeOptionsAtoms,
                            public TrackEventInitAtoms,
                            public TransitionEventInitAtoms,
                            public UIEventInitAtoms,
                            public USSDReceivedEventInitAtoms,
                            public UserProximityEventInitAtoms,
                            public WebGLContextAttributesAtoms,
                            public WebSocketDictAtoms,
                            public WebSocketElementAtoms,
                            public WheelEventInitAtoms,
                            public WifiCommandOptionsAtoms,
                            public WifiResultOptionsAtoms,
                            public WorkerConsoleStackAtoms
{
};

} // namespace dom
} // namespace mozilla


#endif // mozilla_dom_GeneratedAtomList_h__
